==> qtjambi-qt3drender-5.15.4-sources.jar: io/qt/qt3d/render/QScissorTest.java <==
package io.qt.qt3d.render;


/**
 * <p>Discards fragments that fall outside of a certain rectangular portion of the screen</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html">Qt3DRender::QScissorTest</a></p>
 */
public class QScissorTest extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScissorTest.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#bottom-prop">Qt3DRender::QScissorTest::bottomChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="bottom")
    public final Signal1<@io.qt.QtPrimitiveType Integer> bottomChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#height-prop">Qt3DRender::QScissorTest::heightChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="height")
    public final Signal1<@io.qt.QtPrimitiveType Integer> heightChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#left-prop">Qt3DRender::QScissorTest::leftChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="left")
    public final Signal1<@io.qt.QtPrimitiveType Integer> leftChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#width-prop">Qt3DRender::QScissorTest::widthChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="width")
    public final Signal1<@io.qt.QtPrimitiveType Integer> widthChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QScissorTest(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QScissorTest() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#QScissorTest">Qt3DRender::QScissorTest::QScissorTest(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QScissorTest(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QScissorTest instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#bottom-prop">Qt3DRender::QScissorTest::bottom()const</a></p>
     */
    @io.qt.QtPropertyReader(name="bottom")
    @io.qt.QtUninvokable
    public final int bottom(){
        return bottom_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int bottom_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#height-prop">Qt3DRender::QScissorTest::height()const</a></p>
     */
    @io.qt.QtPropertyReader(name="height")
    @io.qt.QtUninvokable
    public final int height(){
        return height_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int height_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#left-prop">Qt3DRender::QScissorTest::left()const</a></p>
     */
    @io.qt.QtPropertyReader(name="left")
    @io.qt.QtUninvokable
    public final int left(){
        return left_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int left_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#bottom-prop">Qt3DRender::QScissorTest::setBottom(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="bottom")
    public final void setBottom(int bottom){
        setBottom_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), bottom);
    }
    
    private native void setBottom_native_int(long __this__nativeId, int bottom);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#height-prop">Qt3DRender::QScissorTest::setHeight(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="height")
    public final void setHeight(int height){
        setHeight_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), height);
    }
    
    private native void setHeight_native_int(long __this__nativeId, int height);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#left-prop">Qt3DRender::QScissorTest::setLeft(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="left")
    public final void setLeft(int left){
        setLeft_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), left);
    }
    
    private native void setLeft_native_int(long __this__nativeId, int left);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#width-prop">Qt3DRender::QScissorTest::setWidth(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="width")
    public final void setWidth(int width){
        setWidth_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), width);
    }
    
    private native void setWidth_native_int(long __this__nativeId, int width);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#width-prop">Qt3DRender::QScissorTest::width()const</a></p>
     */
    @io.qt.QtPropertyReader(name="width")
    @io.qt.QtUninvokable
    public final int width(){
        return width_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int width_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScissorTest(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QScissorTest(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QScissorTest instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QScissorTest.java <==
package io.qt.qt3d.render;


/**
 * <p>Discards fragments that fall outside of a certain rectangular portion of the screen</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html">Qt3DRender::QScissorTest</a></p>
 */
public class QScissorTest extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScissorTest.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#bottom-prop">Qt3DRender::QScissorTest::bottomChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="bottom")
    public final Signal1<@io.qt.QtPrimitiveType Integer> bottomChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#height-prop">Qt3DRender::QScissorTest::heightChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="height")
    public final Signal1<@io.qt.QtPrimitiveType Integer> heightChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#left-prop">Qt3DRender::QScissorTest::leftChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="left")
    public final Signal1<@io.qt.QtPrimitiveType Integer> leftChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#width-prop">Qt3DRender::QScissorTest::widthChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="width")
    public final Signal1<@io.qt.QtPrimitiveType Integer> widthChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QScissorTest(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QScissorTest() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#QScissorTest">Qt3DRender::QScissorTest::QScissorTest(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QScissorTest(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QScissorTest instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#bottom-prop">Qt3DRender::QScissorTest::bottom()const</a></p>
     */
    @io.qt.QtPropertyReader(name="bottom")
    @io.qt.QtUninvokable
    public final int bottom(){
        return bottom_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int bottom_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#height-prop">Qt3DRender::QScissorTest::height()const</a></p>
     */
    @io.qt.QtPropertyReader(name="height")
    @io.qt.QtUninvokable
    public final int height(){
        return height_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int height_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#left-prop">Qt3DRender::QScissorTest::left()const</a></p>
     */
    @io.qt.QtPropertyReader(name="left")
    @io.qt.QtUninvokable
    public final int left(){
        return left_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int left_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#bottom-prop">Qt3DRender::QScissorTest::setBottom(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="bottom")
    public final void setBottom(int bottom){
        setBottom_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), bottom);
    }
    
    private native void setBottom_native_int(long __this__nativeId, int bottom);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#height-prop">Qt3DRender::QScissorTest::setHeight(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="height")
    public final void setHeight(int height){
        setHeight_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), height);
    }
    
    private native void setHeight_native_int(long __this__nativeId, int height);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#left-prop">Qt3DRender::QScissorTest::setLeft(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="left")
    public final void setLeft(int left){
        setLeft_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), left);
    }
    
    private native void setLeft_native_int(long __this__nativeId, int left);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#width-prop">Qt3DRender::QScissorTest::setWidth(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="width")
    public final void setWidth(int width){
        setWidth_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), width);
    }
    
    private native void setWidth_native_int(long __this__nativeId, int width);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qscissortest.html#width-prop">Qt3DRender::QScissorTest::width()const</a></p>
     */
    @io.qt.QtPropertyReader(name="width")
    @io.qt.QtUninvokable
    public final int width(){
        return width_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int width_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScissorTest(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QScissorTest(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QScissorTest instance, QDeclarativeConstructor constructor);
    
}
